==> dibkb_scraper-0.2.1-py3-none-any.whl: dibkb_scraper/models.py <==
from typing import List, Optional, Dict
from dataclasses import dataclass

@dataclass
class Review:
    user: Optional[str] = None
    rating: Optional[str] = None
    title: Optional[str] = None
    text: Optional[str] = None
    date: Optional[str] = None

@dataclass
class StarRating:
    count: Optional[int] = None
    percentage: Optional[int] = None

@dataclass
class RatingStats:
    one_star: StarRating = None
    two_star: StarRating = None
    three_star: StarRating = None
    four_star: StarRating = None
    five_star: StarRating = None

@dataclass
class Ratings:
    rating: Optional[float] = None
    review_count: Optional[int] = None
    rating_stats : RatingStats = None

@dataclass
class RatingPercentage:
    one_star: Optional[int] = None
    two_star: Optional[int] = None
    three_star: Optional[int] = None
    four_star: Optional[int] = None
    five_star: Optional[int] = None

@dataclass
class Description:
    highlights: List[str] = None

@dataclass
class Specifications:
    technical: Dict[str, str] = None
    additional: Dict[str, str] = None
    details: Dict[str, str] = None

@dataclass
class Product:
    title: Optional[str] = None
    image: Optional[List[str]] = None
    price: float = None
    categories: List[str] = None
    description: Description = None
    specifications: Specifications = None
    ratings: Ratings = None
    reviews: List[Review] = None

@dataclass
class AmazonProductResponse:
    product: Product
    error: Optional[str] = None

==> dibkb_scraper-0.2.8-py3-none-any.whl: dibkb_scraper/models.py <==
from typing import Any, List, Optional, Dict
from dataclasses import dataclass
from pydantic import BaseModel

class StarRating(BaseModel):
    count: Optional[int] = None
    percentage: Optional[int] = None

class RatingStats(BaseModel):
    one_star: StarRating = None
    two_star: StarRating = None
    three_star: StarRating = None
    four_star: StarRating = None
    five_star: StarRating = None

class Ratings(BaseModel):
    rating: Optional[float] = None
    review_count: Optional[int] = None
    rating_stats : RatingStats = None

class RatingPercentage(BaseModel):
    one_star: Optional[int] = None
    two_star: Optional[int] = None
    three_star: Optional[int] = None
    four_star: Optional[int] = None
    five_star: Optional[int] = None

class Description(BaseModel):
    highlights: List[str] = None

class Specifications(BaseModel):
    technical: Dict[str, str] = None
    additional: Dict[str, str] = None
    details: Dict[str, str] = None

class Competitor(BaseModel):
    asin: str
    title: str
    img_id: str
    price: float
    
class Product(BaseModel):
    title: Optional[str] = None
    image: Optional[List[str]] = None
    price: float = None
    categories: List[str] = None
    description: Description = None
    specifications: Specifications = None
    ratings: Dict[str,Any] = None
    reviews: List[str] = None
    related_products: List[Competitor] = None


class AmazonProductResponse(BaseModel):
    product: Product
    error: Optional[str] = None
